pub enum MergeStrategy {
Overwrite,
KeepExisting,
}Expand description
Defines the strategy for resolving conflicts when merging two label sets.
Variants
Overwrite
The incoming label will overwrite the existing label if they share the same reference.
KeepExisting
The existing label is preserved; the incoming label is ignored if they share the same reference.